<?php

namespace Drupal\minikanban\Controller;

use Drupal\Core\Entity\Controller\EntityController;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Extension of the entity controller to support kanban params on add pages.
 */
class KanbanContentController extends EntityController {

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected RequestStack $requestStack;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $controller = parent::create($container);
    $controller->requestStack = $container->get('request_stack');
    return $controller;
  }

  /**
   * {@inheritdoc}
   */
  public function addPage($entity_type_id) {
    $response = parent::addPage($entity_type_id);

    $request = $this->requestStack->getCurrentRequest();
    $project = $request->query->get('project');
    $destination = $request->query->get('destination');

    if ($project || $destination) {
      // A list of bundles to choose from.
      if (is_array($response) && ($response['#theme'] ?? NULL) === 'entity_add_list') {
        foreach ($response['#bundles'] as &$bundle) {
          /** @var \Drupal\Core\Url $url */
          $url = $bundle['add_link']->getUrl();
          $params = $url->getOption('query') ?? [];
          if ($project) {
            $params['project'] = $project;
          }
          if ($destination) {
            $params['destination'] = $destination;
          }
          $url->setOption('query', $params);
        }
      }

      // A redirect as there is a single bundle.
      if ($response instanceof RedirectResponse) {
        $url = Url::fromUri($response->getTargetUrl());
        $params = $url->getOption('query') ?? [];
        if ($project) {
          $params['project'] = $project;
        }
        if ($destination) {
          $params['destination'] = $destination;

          // Additionally unset the destination on the current request.
          $request->query->remove('destination');
        }
        $url->setOption('query', $params);
        $response->setTargetUrl($url->toString());
      }
    }

    return $response;
  }

}
